@@ -2,19 +2,33 @@
 ** Copyright (C) 1995, 1996, 1997, 1998 Hewlett-Packard Company
 ** Originally by Kevin Hughes, kev@kevcom.com, 3/11/94
 **
-** This program and library is free software; you can redistribute it and/or
-** modify it under the terms of the GNU (Library) General Public License
-** as published by the Free Software Foundation; either version 2
-** of the License, or any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU (Library) General Public License for more details.
-**
-** You should have received a copy of the GNU (Library) General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+*
+
+    This file is part of Swish-e.
+
+    Swish-e is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    Swish-e is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along  with Swish-e; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    
+    See the COPYING file that accompanies the Swish-e distribution for details
+    of the GNU GPL and the special exception available for linking against
+    the Swish-e library.
+    
+** Mon May  9 15:51:39 CDT 2005
+** added GPL
+** if it was re-written by rasc, is it still copyright HP?
+
+
 **
 ** fixed non-int subscripting pointed out by "gcc -Wall"
 ** SRE 2/22/00
