@@ -1,5 +1,5 @@
 /*
-$Id: docprop.c,v 1.126 2006/10/18 02:58:02 karman Exp $
+$Id: docprop.c 2291 2009-03-31 01:56:00Z karpet $
 **
 
     This file is part of Swish-e.
@@ -358,15 +358,17 @@ propEntry *getDocProperty( RESULT *result, struct metaEntry **meta_entry, int me
     {
         if ( is_meta_entry( *meta_entry, AUTOPROPERTY_RESULT_RANK ) )
         {
-#ifdef RAW_RANK
-            num = PACKLONG( result->rank );
-            return CreateProperty( *meta_entry, (unsigned char *)&num, sizeof( num ), 1, &error_flag );
-#else
+           /* return raw rank if flag set */
+            if (result->db_results->results->sw->ReturnRawRank) {
+                num = PACKLONG( result->rank );
+                return CreateProperty( *meta_entry, (unsigned char *)&num, sizeof( num ), 1, &error_flag );
+            }
+
             int scale_factor = result->db_results->results->rank_scale_factor;
             unsigned long rank_num;
 
             /* scale_factor is zero while sorting, so use the raw rank */
-            /* othersise, scale for display */
+            /* otherwise, scale for display */
 
             if ( scale_factor )
             {
@@ -382,7 +384,6 @@ propEntry *getDocProperty( RESULT *result, struct metaEntry **meta_entry, int me
 
             num = PACKLONG( rank_num );
             return CreateProperty( *meta_entry, (unsigned char *)&num, sizeof( num ), 1, &error_flag );
-#endif
         }
 
         if ( is_meta_entry( *meta_entry, AUTOPROPERTY_REC_COUNT ) )
