@@ -1,19 +1,28 @@
 /*
-**
-** This program and library is free software; you can redistribute it and/or
-** modify it under the terms of the GNU (Library) General Public License
-** as published by the Free Software Foundation; either version 2
-** of the License, or any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU (Library) General Public License for more details.
-**
-** You should have received a copy of the GNU (Library) General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-**
+
+    This file is part of Swish-e.
+
+    Swish-e is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    Swish-e is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along  with Swish-e; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    
+    See the COPYING file that accompanies the Swish-e distribution for details
+    of the GNU GPL and the special exception available for linking against
+    the Swish-e library.
+    
+** Mon May  9 15:51:39 CDT 2005
+** added GPL
+
 **
 **
 ** 2001-05-07 jmruiz init coding
@@ -39,41 +48,41 @@
 #include "error.h"
 
 
-void dump_index_file_list( SWISH *sw, IndexFILE *indexf, int begin, int maxhits ) 
+void dump_index_file_list( SWISH *sw, IndexFILE *indexf, int filenum, int maxhits )
 {
-    int     i;
-    int     end = indexf->header.totalfiles;
+    /* if maxhits is 0 then show all */
+    if ( !maxhits )
+        maxhits = indexf->header.totalfiles;
 
-    i = begin ? begin - 1 : 0;
+    if ( !filenum )
+        filenum = 1;
 
-    if ( i >= indexf->header.totalfiles )
-    {
-        printf("Hey, there are only %d files\n", indexf->header.totalfiles );
-        exit(-1);
-    }
-
-    end = indexf->header.totalfiles;
-
-    if ( maxhits > 0 )
-    {
-        end = i + maxhits;
-        if ( end > indexf->header.totalfiles )
-            end = indexf->header.totalfiles;
-    }
-
-   
     printf("\n\n-----> FILES in index %s <-----\n", indexf->line );
 
-    for (; i < end; i++)
+
+    while ( filenum <= indexf->header.totalfiles && maxhits )
     {
         FileRec fi;
+        int     words = 0;
+
+
+        /* See if file was deleted */
+        if (indexf->header.removedfiles)
+        {
+            /* Assumes that zero words means that the file was deleted -- should likey be a macro */
+            words = getTotalWordsInFile( indexf, filenum );
+            if ( !words )
+            {
+                filenum++;
+                continue;  /* skip this file -- it has been deleted */
+            }
+        }
 
         memset( &fi, 0, sizeof( FileRec ) );
-        
-        fi.filenum = i+1;
+        fi.filenum = filenum;
 
         fflush(stdout);
-        printf("Dumping File Properties for File Number: %d\n", i+1);
+        printf("Dumping File Properties for File Number: %d\n", filenum);
 
 
         dump_file_properties( indexf, &fi );
@@ -81,8 +90,12 @@ void dump_index_file_list( SWISH *sw, IndexFILE *indexf, int begin, int maxhits
 
 
         printf("ReadAllDocProperties:\n");
-        fi.docProperties =  ReadAllDocPropertiesFromDisk( indexf, i+1 );
+        fi.docProperties =  ReadAllDocPropertiesFromDisk( indexf, filenum );
         dump_file_properties( indexf, &fi );
+
+        if ( words )
+            printf("Filenum and words in this file: %d %d\n", filenum, words );
+
         freefileinfo( &fi );
 
         printf("\n");
@@ -121,9 +134,9 @@ void dump_index_file_list( SWISH *sw, IndexFILE *indexf, int begin, int maxhits
                         efree(buffer);
                     }
                 }
-        
 
-        
+
+
                 freeProperty( p );
             }
         }
@@ -131,13 +144,37 @@ void dump_index_file_list( SWISH *sw, IndexFILE *indexf, int begin, int maxhits
 
 
         freefileinfo(&fi);
+        maxhits--;
+        filenum++;
     }
-    printf("\nNumber of File Entries: %d\n", indexf->header.totalfiles);
     fflush(stdout);
 }
 
 
+/* prints out the number of words in every file in the index */
+/* This will generate an error if not indexed with totalwords and not btree */
 
+void    dump_word_count( SWISH *sw, IndexFILE *indexf, int filenum, int maxhits )
+{
+    /* if maxhits is 0 then show all */
+    if ( !maxhits )
+        maxhits = indexf->header.totalfiles;
+
+    if ( !filenum )
+        filenum = 1;
+
+    while ( filenum <= indexf->header.totalfiles && maxhits )
+    {
+        int words = getTotalWordsInFile( indexf, filenum );
+        if ( words )
+        {
+            printf("%d %d\n", filenum, words );
+            maxhits++;
+        }
+
+        filenum++;
+    }
+}
 
 /* Prints out the data in an index DB */
 void    DB_decompress(SWISH * sw, IndexFILE * indexf, int begin, int maxhits)
@@ -149,17 +186,18 @@ void    DB_decompress(SWISH * sw, IndexFILE * indexf, int begin, int maxhits)
             frequency,
             metaID,
             tmpval,
-            filenum,
-           *posdata;
+            printedword,
+            filenum;
+    unsigned int       *posdata;
     int     metadata_length;
     char    word[2];
     char   *resultword;
     unsigned char   *worddata, *s, *start, flag;
     int     sz_worddata, saved_bytes;
-    long    wordID;
+    sw_off_t    wordID;
+
 
 
-    
     indexf->DB = DB_Open(sw, indexf->line,DB_READ);
     if ( sw->lasterror )
         SwishAbortLastError( sw );
@@ -174,7 +212,7 @@ void    DB_decompress(SWISH * sw, IndexFILE * indexf, int begin, int maxhits)
 
         /* Read header */
     read_header(sw, &indexf->header, indexf->DB);
-    
+
 
     if (DEBUG_MASK & (DEBUG_INDEX_ALL | DEBUG_INDEX_HEADER) )
     {
@@ -199,13 +237,61 @@ void    DB_decompress(SWISH * sw, IndexFILE * indexf, int begin, int maxhits)
             word[1] = '\0';
             DB_ReadFirstWordInvertedIndex(sw, word,&resultword,&wordID,indexf->DB);
 
-            while(wordID)
+            while(wordID && (((int)((unsigned char)resultword[0]))== j))
             {
+              if(indexf->header.removedfiles)
+              {
+                /* We need to Read Word's data to check that there is
+                ** at least one file that has not been removed */
+                DB_ReadWordData(sw, wordID, &worddata, &sz_worddata, &saved_bytes, indexf->DB);
+                uncompress_worddata(&worddata, &sz_worddata, saved_bytes);
+
+                /* parse and print word's data */
+                s = worddata;
+
+                tmpval = uncompress2(&s);     /* tfrequency */
+                metaID = uncompress2(&s);     /* metaID */
+                metadata_length = uncompress2(&s);
+
+                filenum = 0;
+                start = s;
+                while(1)
+                {                   /* Read on all items */
+                    uncompress_location_values(&s,&flag,&tmpval,&frequency);
+                    filenum += tmpval;
+                    posdata = (unsigned int *) emalloc(frequency * sizeof(int));
+                    uncompress_location_positions(&s,flag,frequency,posdata);
+
+                    /* 2004/09 jmruiz. Need to check for one file not being marked as deleted */
+                    if (DB_CheckFileNum(sw,filenum,indexf->DB))
+                    {
+                        printf("%s\n",resultword);
+                        break;
+                    }
+                    /* Check for end of worddata */
+                    if ((s - worddata) == sz_worddata)
+                        break;   /* End of worddata */
+
+                    /* Check for end of current metaID data */
+                    if ( metadata_length == (s - start))
+                    {
+                        filenum = 0;
+                        metaID = uncompress2(&s);
+                        metadata_length = uncompress2(&s);
+                        start = s;
+                    }
+
+                }
+                efree(posdata);
+                efree(worddata);
+              }
+              else
                 printf("%s\n",resultword);
 
-                
+              efree(resultword);
+              DB_ReadNextWordInvertedIndex(sw, word,&resultword,&wordID,indexf->DB);
+              if (wordID && ((int)((unsigned char)resultword[0]))!= j)
                 efree(resultword);
-                DB_ReadNextWordInvertedIndex(sw, word,&resultword,&wordID,indexf->DB);
 
             }
         }
@@ -224,8 +310,8 @@ void    DB_decompress(SWISH * sw, IndexFILE * indexf, int begin, int maxhits)
             if ( indexf->header.metaEntryArray[i]->metaID > end_meta )
                 end_meta = indexf->header.metaEntryArray[i]->metaID;
 
-        meta_used = emalloc( sizeof(int) * ( end_meta + 1) );  
-    
+        meta_used = emalloc( sizeof(int) * ( end_meta + 1) );
+
         /* _META only reports which tags the words are found in */
         for(i = 0; i <= end_meta; i++)
             meta_used[i] = 0;
@@ -240,8 +326,10 @@ void    DB_decompress(SWISH * sw, IndexFILE * indexf, int begin, int maxhits)
 
             while(wordID && (((int)((unsigned char)resultword[0]))== j))
             {
-                printf("\n%s",resultword);
-
+                /* Flag to know if we must print a word or not */
+                /* Words with all the files marked as deleted shoud not be
+                ** printed */
+                printedword = 0;
                 /* Read Word's data */
                 DB_ReadWordData(sw, wordID, &worddata, &sz_worddata, &saved_bytes, indexf->DB);
                 uncompress_worddata(&worddata, &sz_worddata, saved_bytes);
@@ -259,18 +347,26 @@ void    DB_decompress(SWISH * sw, IndexFILE * indexf, int begin, int maxhits)
                 {                   /* Read on all items */
                     uncompress_location_values(&s,&flag,&tmpval,&frequency);
                     filenum += tmpval;
-                    posdata = (int *) emalloc(frequency * sizeof(int));
+                    posdata = (unsigned int *) emalloc(frequency * sizeof(int));
                     uncompress_location_positions(&s,flag,frequency,posdata);
 
+                    /* 2004/09 jmruiz. Need to check for files marked as deleted */
+                    if ((!indexf->header.removedfiles) || DB_CheckFileNum(sw,filenum,indexf->DB))
+                    {
+                    if(!printedword)
+                    {
+                        printf("\n%s",resultword);
+                        printedword = 1;
+                    }
 
                     // if (sw->verbose >= 4)
                     if (DEBUG_MASK & (DEBUG_INDEX_ALL|DEBUG_INDEX_WORDS_FULL))
                     {
                         struct metaEntry    *m;
-                        
+
                         printf("\n Meta:%d", metaID);
 
-                        
+
                         /* Get path from property list */
                         if ( (m = getPropNameByName( &sw->indexlist->header, AUTOPROPERTY_DOCPATH )) )
                         {
@@ -290,11 +386,11 @@ void    DB_decompress(SWISH * sw, IndexFILE * indexf, int begin, int maxhits)
 
                             printf(" %s", s );
                             efree( s );
-                            
+
                         }
                         else
                             printf(" Failed to lookup meta entry");
-                            
+
 
                         printf(" Freq:%d", frequency);
                         printf(" Pos/Struct:");
@@ -307,7 +403,6 @@ void    DB_decompress(SWISH * sw, IndexFILE * indexf, int begin, int maxhits)
                         printf(" %d", filenum);
                         printf(" %d (", frequency);
                     }
-                    
 
                     for (i = 0; i < frequency; i++)
                     {
@@ -327,13 +422,14 @@ void    DB_decompress(SWISH * sw, IndexFILE * indexf, int begin, int maxhits)
                                  printf("%d/%x", GET_POSITION(posdata[i]),GET_STRUCTURE(posdata[i]));
                         }
                     }
-
-                    efree(posdata);
-
                     if ( DEBUG_MASK & DEBUG_INDEX_WORDS )
                         printf(")]");
 
-                    /* Check for enf of worddata */
+                    }  /* End of DB_CheckFileNum */
+
+                    efree(posdata);
+
+                    /* Check for end of worddata */
                     if ((s - worddata) == sz_worddata)
                         break;   /* End of worddata */
 
@@ -356,7 +452,7 @@ void    DB_decompress(SWISH * sw, IndexFILE * indexf, int begin, int maxhits)
                         meta_used[i] = 0;
                     }
                 }
-                
+
 
                 if ( !( DEBUG_MASK & DEBUG_INDEX_WORDS_META ))
                     printf("\n");
@@ -364,6 +460,8 @@ void    DB_decompress(SWISH * sw, IndexFILE * indexf, int begin, int maxhits)
                 efree(worddata);
                 efree(resultword);
                 DB_ReadNextWordInvertedIndex(sw, word,&resultword,&wordID,indexf->DB);
+                if (wordID && ((int)((unsigned char)resultword[0]))!= j)
+                  efree(resultword);
             }
         }
         DB_EndReadWords(sw, indexf->DB);
@@ -381,23 +479,29 @@ void    DB_decompress(SWISH * sw, IndexFILE * indexf, int begin, int maxhits)
         dump_index_file_list( sw, indexf, begin, maxhits );
 
 
-    DB_Close(sw, indexf->DB);
+    /* just print filenums and number of words per file for word ranking */
+    if (DEBUG_MASK & DEBUG_INDEX_WORD_COUNT )
+        dump_word_count( sw, indexf, begin, maxhits );
 
+    DB_Close(sw, indexf->DB);
 }
 
 
 int check_sorted_index( SWISH *sw, IndexFILE *indexf, struct metaEntry *m )
 {
-    unsigned char *buffer;
-    int     sz_buffer;
+    unsigned char *buffer = NULL;
+    int     sz_buffer = 0;
 
     DB_InitReadSortedIndex(sw, indexf->DB);
-    
+
     /* Get the sorted index of the property */
     DB_ReadSortedIndex(sw, m->metaID, &buffer, &sz_buffer, indexf->DB);
 
+    /* For incremental index. It will be released when closing indexf->DB */
+#ifndef USE_BTREE
     if ( sz_buffer )
         efree( buffer );
+#endif
 
     /* Table doesn't exist */
     return sz_buffer;
@@ -413,17 +517,17 @@ void dump_metanames( SWISH *sw, IndexFILE *indexf, int check_presorted )
     for(i = 0; i < indexf->header.metaCounter; i++)
     {
         meta_entry = indexf->header.metaEntryArray[i];
-        
+
         printf("%20s : id=%2d type=%2d ",meta_entry->metaName, meta_entry->metaID, meta_entry->metaType);
 
         if ( is_meta_index( meta_entry ) )
             printf(" META_INDEX  Rank Bias=%3d", meta_entry->rank_bias );
-            
-            
+
+
 
         if ( is_meta_internal( meta_entry ) )
             printf(" META_INTERNAL");
-            
+
 
         if ( is_meta_property( meta_entry ) )
         {
@@ -431,7 +535,12 @@ void dump_metanames( SWISH *sw, IndexFILE *indexf, int check_presorted )
 
             if  ( is_meta_string(meta_entry) )
             {
-                printf("STRING(case:%s) ", is_meta_ignore_case(meta_entry)? "ignore" : "compare");
+                printf("STRING(case:%s) ",
+                    is_meta_use_strcoll(meta_entry)
+                        ? "strcoll"
+                        : is_meta_ignore_case(meta_entry)
+                            ? "ignore"
+                            : "compare");
                 printf("SortKeyLen: %d ", meta_entry->sort_len );
             }
 
@@ -446,6 +555,7 @@ void dump_metanames( SWISH *sw, IndexFILE *indexf, int check_presorted )
         }
 
 
+
         if ( check_presorted && check_sorted_index( sw, indexf, meta_entry)  )
             printf(" *presorted*");
 
@@ -461,7 +571,7 @@ void dump_metanames( SWISH *sw, IndexFILE *indexf, int check_presorted )
 
 
         printf("\n");
-        
+
     }
     printf("\n");
 }
@@ -474,14 +584,14 @@ void dump_metanames( SWISH *sw, IndexFILE *indexf, int check_presorted )
 void dump_file_properties(IndexFILE * indexf, FileRec *fi )
 {
     int j;
-	propEntry *prop;
+        propEntry *prop;
     struct metaEntry *meta_entry;
 
-	if ( !fi->docProperties )  /* may not be any properties */
-	{
-	    printf(" (No Properties)\n");
-	    return;
-	}
+        if ( !fi->docProperties )  /* may not be any properties */
+        {
+            printf(" (No Properties)\n");
+            return;
+        }
 
     for (j = 0; j < fi->docProperties->n; j++)
     {
@@ -490,7 +600,7 @@ void dump_file_properties(IndexFILE * indexf, FileRec *fi )
 
         meta_entry = getPropNameByID( &indexf->header, j );
         prop = fi->docProperties->propEntry[j];
-        
+
         dump_single_property( prop, meta_entry );
     }
 }
@@ -516,7 +626,7 @@ void dump_single_property( propEntry *prop, struct metaEntry *meta_entry )
     i = prop ? prop->propLen : 0;
 
     printf("  %20s:%2d (%3d) %c:", meta_entry->metaName, meta_entry->metaID, i, proptype );
-    
+
 
     if ( !prop )
     {
@@ -532,7 +642,7 @@ void dump_single_property( propEntry *prop, struct metaEntry *meta_entry )
     {
         if ( 1 ) // ( isprint( (int)propstr[i] ))
             printf("%c", propstr[i] );
-            
+
         else if ( propstr[i] == '\n' )
             printf("\n");
 
@@ -547,7 +657,7 @@ void dump_single_property( propEntry *prop, struct metaEntry *meta_entry )
         }
     }
     printf("\"\n");
-            
+
     efree( propstr );
 }
 
