@@ -1,5 +1,5 @@
 /*
-$Id: proplimit.c,v 1.48 2005/05/12 15:41:05 karman Exp $
+$Id: proplimit.c 1946 2007-10-22 14:56:35Z karpet $
 **
     This file is part of Swish-e.
 
@@ -152,17 +152,18 @@ void SwishResetSearchLimit( SEARCH_OBJECT *srch )
     int         metaID;
     
 
-    if ( !srch->limits_prepared )
-        return;
-
 
     /* Free up the input parameters */
     ClearLimitParams( srch->limit_params );
     srch->limit_params = NULL;
 
-            
 
     /* Free up the stored limits for each meta entry */
+
+    if ( !srch->limits_prepared )
+        return;
+
+
     while ( indexf )
     {
         PROP_LIMITS *index_limits = srch->prop_limits[index_count++];
@@ -187,7 +188,7 @@ void SwishResetSearchLimit( SEARCH_OBJECT *srch )
                 index_limits[metaID].hiPropRange = NULL;
             }
         }
-        
+
 
         indexf = indexf->next;
     }
@@ -238,6 +239,7 @@ void ClearLimitParams( LIMIT_PARAMS *params )
 ********************************************************************/
 int SwishSetSearchLimit(SEARCH_OBJECT *srch, char *propertyname, char *low, char *hi)
 {
+    LIMIT_PARAMS *params;
     reset_lasterror( srch->sw );
     
     if ( srch->limits_prepared )
@@ -246,9 +248,15 @@ int SwishSetSearchLimit(SEARCH_OBJECT *srch, char *propertyname, char *low, char
         return 0;
     }
 
-    srch->limit_params = setlimit_params( srch->sw, srch->limit_params, propertyname, low, hi );
-    return ( srch->sw->lasterror == 0 );
+    /* Add new limit parameter to list */
+    params  = setlimit_params( srch->sw, srch->limit_params, propertyname, low, hi );
 
+    /* Only reset list if no error */
+    if ( params )
+        srch->limit_params = params;
+
+
+    return ( srch->sw->lasterror == 0 );
 }
 
 /* This just sets the LIMIT_PARAMS struct -- useful when don't have a SEARCH_OBJECT */
