@@ -1,5 +1,5 @@
 /*
-$Id: result_sort.c,v 1.89 2005/05/12 15:41:08 karman Exp $
+$Id: result_sort.c 2271 2009-03-16 13:43:15Z karpet $
 **
 
     This file is part of Swish-e.
@@ -51,8 +51,6 @@ $Id: result_sort.c,v 1.89 2005/05/12 15:41:08 karman Exp $
 // #define DEBUGSORT 1
 
 
-
-
 /*****************************************************************************
 * compare_results_single_index - qsort compare function
 *
@@ -325,7 +323,7 @@ static int sort_single_index_results( DB_RESULTS *db_results )
     while ( cur_result )
     {
         /* Set an index number which can be used to point into the sort_data->key array. */
-        /* tfrequency is not after rank calculations (or at all?) */
+        /* tfrequency is not used after rank calculations */
 
         cur_result->tfrequency = results_in_index++;
 
@@ -467,7 +465,12 @@ int  sortresults(RESULTS_OBJECT *results)
     /* set rank scaling factor based on the largest rank found of all results */
 
     if (results->bigrank)
+    {
+        if ( DEBUG_RANK ) {
+            fprintf(stderr, "bigrank found: %d\n", results->bigrank );
+        }
         results->rank_scale_factor = 10000000 / results->bigrank;
+    }
     else
         results->rank_scale_factor = 10000;
 
