@@ -1,5 +1,5 @@
 /*
-$Id: search.c,v 1.148 2006/10/18 15:07:51 karman Exp $
+$Id: search.c 2291 2009-03-31 01:56:00Z karpet $
 **
 ** Copyright (C) 1995, 1996, 1997, 1998 Hewlett-Packard Company
 ** Originally by Kevin Hughes, kev@kevcom.com, 3/11/94
@@ -142,7 +142,6 @@ $Id: search.c,v 1.148 2006/10/18 15:07:51 karman Exp $
 
 #include "rank.h"
 
-
 /* ------ static fucntions ----------- */
 static int init_sort_propIDs( DB_RESULTS *db_results, struct swline *sort_word, DB_RESULTS *last );
 static void query_index( DB_RESULTS *db_results );
@@ -175,12 +174,21 @@ static void make_db_res_and_free(RESULT_LIST *l_res);
 
 void SwishRankScheme(SWISH *sw, int scheme)
 {
-	
     sw->RankScheme = scheme;
-    
 }
 
 
+/*********************************************************************
+* SwishReturnRawRank -- return unscaled swishrank values
+* karman - Mon Mar 30 20:51:02 CDT 2009
+*
+*********************************************************************/
+
+void SwishReturnRawRank(SWISH *sw, int flag)
+{
+    sw->ReturnRawRank = flag;
+}
+
 
 
 /****************************************************************
@@ -290,6 +298,10 @@ void SwishSetStructure( SEARCH_OBJECT *srch, int structure )
         srch->structure = structure;
 }
 
+int SwishGetStructure( SEARCH_OBJECT *srch )
+{
+    return srch ? srch->structure : 0;
+}
 
 void SwishPhraseDelimiter( SEARCH_OBJECT *srch, char delimiter )
 {
@@ -298,6 +310,11 @@ void SwishPhraseDelimiter( SEARCH_OBJECT *srch, char delimiter )
 }
 
 
+char SwishGetPhraseDelimiter(SEARCH_OBJECT *srch)
+{
+    return srch ? srch->PhraseDelimiter : 0;
+}
+
 
 void SwishSetSort( SEARCH_OBJECT *srch, char *sort )
 {
@@ -1573,7 +1590,7 @@ static RESULT_LIST *getfileinfo(DB_RESULTS *db_results, char *word, int metaID)
     rLen = 0;
     tLen = strlen(word);
     // Check for first "?" in current word (not reverse)
-    if ((q = strchr(word, '?')))
+    if ((q = (unsigned char*)strchr(word, '?')))
     {
         if (q != (unsigned char*)word && *(q - 1) == '\\') /* Check for an escaped * */
         {
@@ -1584,13 +1601,13 @@ static RESULT_LIST *getfileinfo(DB_RESULTS *db_results, char *word, int metaID)
             /* Check if it is at the end of the word */
             if (q == ((unsigned char*)word + strlen(word) - 1))
             {
-                strcpy(remains, q);   // including the last "?"
+                strcpy(remains, (char*)q);   // including the last "?"
                 rLen = strlen(remains);
                 word[strlen(word) - 1] = '\0';
             }
             else
             {
-                strcpy(remains, q);   // including the first "?"
+                strcpy(remains, (char*)q);   // including the first "?"
                 rLen = strlen(remains);
                 *q = '\0';
             }
@@ -1631,7 +1648,7 @@ static RESULT_LIST *getfileinfo(DB_RESULTS *db_results, char *word, int metaID)
             return NULL;
         }
         else
-            strcpy(myWord, resultword);   // Remember the word
+            strcpy(myWord, (char*)resultword);   // Remember the word
             
         efree(resultword);   /* Do not need it */
     }
@@ -1702,7 +1719,7 @@ static RESULT_LIST *getfileinfo(DB_RESULTS *db_results, char *word, int metaID)
             if (! wordID)
                 break;          /* no more data */
             else
-              strcpy(myWord, resultword);
+              strcpy(myWord, (char*)resultword);
 
             efree(resultword);  /* Do not need it (although might be useful for highlighting some day) */
 
@@ -1818,7 +1835,7 @@ static RESULT_LIST *getfileinfo(DB_RESULTS *db_results, char *word, int metaID)
                 break;          /* no more data */
 
             else
-                strcpy(myWord, resultword); // remember the word
+                strcpy(myWord, (char*)resultword); // remember the word
 
             efree(resultword);  /* Do not need it (although might be useful for highlighting some day) */
         }
@@ -2266,9 +2283,11 @@ static RESULT_LIST *andresultlists(DB_RESULTS *db_results, RESULT_LIST * l_r1, R
             newRank = ((r1->rank * andLevel) + r2->rank) / (andLevel + 1);
 
 
-#ifdef DEBUG_RANK
-    fprintf( stderr, "\n----\nFile num: %d  1st score: %d  2nd score: %d  andLevel: %d  newRank:  %d\n----\n", r1->filenum, r1->rank, r2->rank, andLevel, newRank );
-#endif
+            if ( DEBUG_RANK )
+            {
+                fprintf( stderr, "File num: %d  1st score: %d  2nd score: %d  andLevel: %d  newRank:  %d\n----\n", 
+                    r1->filenum, r1->rank, r2->rank, andLevel, newRank );
+            }
             
 
             if(!new_results_list)
@@ -2321,8 +2340,9 @@ static RESULT_LIST *orresultlists(DB_RESULTS *db_results, RESULT_LIST * l_r1, RE
            *tmp;
     RESULT_LIST *new_results_list = NULL;
     RESULTS_OBJECT *results = db_results->results;
-
-
+    /* TODO use to detect rank size overflow 
+    unsigned int max_rank_size = 256 ^ sizeof(int);
+    */
 
     /* If either list is empty, just return the other */
     if (l_r1 == NULL)
@@ -2352,9 +2372,9 @@ static RESULT_LIST *orresultlists(DB_RESULTS *db_results, RESULT_LIST * l_r1, RE
 
         else /* Matching file number */
         {
-            int result_size;
+            int result_size, r1rank, r2rank;
             
-            /* Create a new RESULT - Should be a function to creete this, I'd think */
+            /* Create a new RESULT - Should be a function to create this, I'd think */
 
             result_size = sizeof(RESULT) + ( (r1->frequency + r2->frequency - 1) * sizeof(int) );
             rp = (RESULT *) Mem_ZoneAlloc(results->resultSearchZone, result_size );
@@ -2362,11 +2382,18 @@ static RESULT_LIST *orresultlists(DB_RESULTS *db_results, RESULT_LIST * l_r1, RE
 
             rp->fi.filenum = rp->filenum = r1->filenum;
 
-            rp->rank = ( r1->rank + r2->rank) * 2;  /* bump up the or terms */
+            /* TODO *2 breaks sort if rank > 2^32 */
+            
+            r1rank = r1->rank;
+            r2rank = r2->rank;
+                        
+            rp->rank = ( r1rank + r2rank );  /* bump up the or terms */
 	    
-#ifdef DEBUG_RANK
-    fprintf( stderr, "\n----\nFile num: %d  1st score: %d  2nd score: %d  newRank:  %d\n----\n", r1->filenum, r1->rank, r2->rank, rp->rank );
-#endif
+            if (DEBUG_RANK)
+            {
+                fprintf( stderr, "----\nFile num: %d  1st score: %d  2nd score: %d  newRank:  %d\n", 
+                    r1->filenum, r1->rank, r2->rank, rp->rank );
+            }
 
             rp->tfrequency = 0;
             rp->frequency = r1->frequency + r2->frequency;
