@@ -1,7 +1,7 @@
 /*
 ** stemmer.h
 
-$Id: stemmer.h,v 1.18 2006/11/11 16:17:53 karman Exp $
+$Id: stemmer.h 1949 2007-10-24 03:02:08Z karpet $
 
     This file is part of Swish-e.
 
@@ -58,7 +58,9 @@ typedef enum {
     FUZZY_STEMMING_SE,
     FUZZY_STEMMING_DK,
     FUZZY_STEMMING_RU,
-    FUZZY_STEMMING_FI
+    FUZZY_STEMMING_FI,
+    FUZZY_STEMMING_RO,
+    FUZZY_STEMMING_HU
 } FuzzyIndexType;
 
 
