@@ -1,5 +1,5 @@
 /*
-$Id: swish_words.c,v 1.46 2006/08/27 20:22:54 karman Exp $
+$Id: swish_words.c 2145 2008-06-06 02:09:42Z karpet $
 
 
     This file is part of Swish-e.
@@ -917,7 +917,17 @@ static struct swline *ignore_words_in_query(DB_RESULTS *db_results, struct swlin
                 break;
             }
                     
-
+            /* 
+                is the token of an ok length to consider? 
+                treat min/max length like stopwords 
+            */
+            if (    strlen(cur_token->line) < indexf->header.minwordlimit
+                ||  strlen(cur_token->line) > indexf->header.maxwordlimit
+            ) {
+                db_results->removed_stopwords = addswline( db_results->removed_stopwords, cur_token->line );
+                stop_word_removed++;
+                remove = 1;
+            }
 
             /* Finally, is it a stop word? */
 
